@@ -1,7 +1,7 @@
 package Perinci::Sub::GetArgs::Argv;
 
-our $DATE = '2015-02-07'; # DATE
-our $VERSION = '0.62'; # VERSION
+our $DATE = '2015-03-06'; # DATE
+our $VERSION = '0.63'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,7 +27,7 @@ $SPEC{':package'} = {
     summary => 'Get subroutine arguments from command line arguments (@ARGV)',
 };
 
-my $re_simple_scalar = qr/^(str|num|int|float|bool|buf)$/;
+my $re_simple_scalar = qr/^(str|num|int|float|bool|buf|re)$/;
 
 # retun ($success?, $errmsg, $res)
 sub _parse_json {
@@ -1027,7 +1027,7 @@ Perinci::Sub::GetArgs::Argv - Get subroutine arguments from command line argumen
 
 =head1 VERSION
 
-This document describes version 0.62 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-02-07.
+This document describes version 0.63 of Perinci::Sub::GetArgs::Argv (from Perl distribution Perinci-Sub-GetArgs-Argv), released on 2015-03-06.
 
 =head1 SYNOPSIS
 
